@@ -12,7 +12,7 @@ from prompt_toolkit.layout.dimension import LayoutDimension
 from prompt_toolkit.layout.lexers import SimpleLexer
 from prompt_toolkit.layout.margins import PromptMargin
 from prompt_toolkit.layout.menus import CompletionsMenu, MultiColumnCompletionsMenu
-from prompt_toolkit.layout.processors import ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor, HighlightMatchingBracketProcessor
+from prompt_toolkit.layout.processors import ConditionalProcessor, AppendAutoSuggestion, HighlightSearchProcessor, HighlightSelectionProcessor, HighlightMatchingBracketProcessor, Processor, Transformation
 from prompt_toolkit.layout.screen import Char
 from prompt_toolkit.layout.toolbars import CompletionsToolbar, ArgToolbar, SearchToolbar, ValidationToolbar, SystemToolbar, TokenListToolbar
 from prompt_toolkit.layout.utils import token_list_width
@@ -34,6 +34,20 @@ __all__ = (
 )
 
 
+# DisplayMultipleCursors: Only for prompt_toolkit>=1.0.8
+try:
+    from prompt_toolkit.layout.processors import DisplayMultipleCursors
+except ImportError:
+    class DisplayMultipleCursors(Processor):
+        " Dummy. "
+        def __init__(self, *a):
+            pass
+
+        def apply_transformation(self, cli, document, lineno,
+                                 source_to_display, tokens):
+            return Transformation(tokens)
+
+
 class CompletionVisualisation:
     " Visualisation method for the completions. "
     NONE = 'none'
@@ -208,7 +222,14 @@ def signature_toolbar(python_input):
 
             append((Signature.Operator, '('))
 
-            for i, p in enumerate(sig.params):
+            try:
+                enumerated_params = enumerate(sig.params)
+            except AttributeError:
+                # Workaround for #136: https://github.com/jonathanslenders/ptpython/issues/136
+                # AttributeError: 'Lambda' object has no attribute 'get_subscope_by_name'
+                return []
+
+            for i, p in enumerated_params:
                 # Workaround for #47: 'p' is None when we hit the '*' in the signature.
                 #                     and sig has no 'index' attribute.
                 # See: https://github.com/jonathanslenders/ptpython/issues/47
@@ -483,6 +504,7 @@ def create_layout(python_input, key_bindings_manager,
                         filter=HasFocus(SEARCH_BUFFER),
                     ),
                     HighlightSelectionProcessor(),
+                    DisplayMultipleCursors(DEFAULT_BUFFER),
                     # Show matching parentheses, but only while editing.
                     ConditionalProcessor(
                         processor=HighlightMatchingBracketProcessor(chars='[](){}'),
